@@ -8,9 +8,9 @@ test_that("fit_curves works for different combination of inputs", {
                                                        random = list(id = ~ 1),
                                                        data = FulanusPhysiology)))
 
-  expect_is(perf_functions$tpc_size, "list")
-  expect_is(perf_functions$tpc_size$output[[1]], "lme")
-  expect_is(perf_functions$tpc_size$output[[2]], "gam")
-  expect_is(perf_functions$tpc_size$predict, "function")
+  testthat::expect_is(perf_functions$tpc_size, "list")
+  testthat::expect_is(perf_functions$tpc_size$output[[1]], "lme")
+  testthat::expect_is(perf_functions$tpc_size$output[[2]], "gam")
+  testthat::expect_is(perf_functions$tpc_size$predict, "function")
 
 })
